#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_SAFE_MIN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_SAFE_MIN_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/scalar/safe_min.hpp>

#endif
